@@ -20,14 +20,14 @@ virtualenv-app-data
          ├── py_info.py
          ├── debug.py
          └── _virtualenv.py
-"""
+"""  # noqa: D415
 
 from __future__ import annotations
 
 import json
 import logging
-from abc import ABCMeta
-from contextlib import contextmanager
+from abc import ABC
+from contextlib import contextmanager, suppress
 from hashlib import sha256
 
 from virtualenv.util.lock import ReentrantFileLock
@@ -37,30 +37,30 @@ from virtualenv.version import __version__
 
 from .base import AppData, ContentStore
 
+LOGGER = logging.getLogger(__name__)
+
 
 class AppDataDiskFolder(AppData):
-    """
-    Store the application data on the disk within a folder layout.
-    """
+    """Store the application data on the disk within a folder layout."""
 
     transient = False
     can_update = True
 
-    def __init__(self, folder):
+    def __init__(self, folder) -> None:
         self.lock = ReentrantFileLock(folder)
 
-    def __repr__(self):
+    def __repr__(self) -> str:
         return f"{type(self).__name__}({self.lock.path})"
 
-    def __str__(self):
+    def __str__(self) -> str:
         return str(self.lock.path)
 
     def reset(self):
-        logging.debug("reset app data folder %s", self.lock.path)
+        LOGGER.debug("reset app data folder %s", self.lock.path)
         safe_delete(self.lock.path)
 
     def close(self):
-        """do nothing"""
+        """Do nothing."""
 
     @contextmanager
     def locked(self, path):
@@ -70,10 +70,7 @@ class AppDataDiskFolder(AppData):
 
     @contextmanager
     def extract(self, path, to_folder):
-        if to_folder is not None:
-            root = ReentrantFileLock(to_folder())
-        else:
-            root = self.lock / "unzip" / __version__
+        root = ReentrantFileLock(to_folder()) if to_folder is not None else self.lock / "unzip" / __version__
         with root.lock_for_key(path.name):
             dest = root.path / path.name
             if not dest.exists():
@@ -88,7 +85,7 @@ class AppDataDiskFolder(AppData):
         return PyInfoStoreDisk(self.py_info_at, path)
 
     def py_info_clear(self):
-        """ """
+        """clear py info."""
         py_info_folder = self.py_info_at
         with py_info_folder:
             for filename in py_info_folder.path.iterdir():
@@ -110,12 +107,12 @@ class AppDataDiskFolder(AppData):
         return self.lock.path / "wheel" / for_py_version / "image" / "1" / name
 
 
-class JSONStoreDisk(ContentStore, metaclass=ABCMeta):
-    def __init__(self, in_folder, key, msg, msg_args):
+class JSONStoreDisk(ContentStore, ABC):
+    def __init__(self, in_folder, key, msg, msg_args) -> None:
         self.in_folder = in_folder
         self.key = key
         self.msg = msg
-        self.msg_args = msg_args + (self.file,)
+        self.msg_args = (*msg_args, self.file)
 
     @property
     def file(self):
@@ -128,22 +125,21 @@ class JSONStoreDisk(ContentStore, metaclass=ABCMeta):
         data, bad_format = None, False
         try:
             data = json.loads(self.file.read_text(encoding="utf-8"))
-            logging.debug(f"got {self.msg} from %s", *self.msg_args)
-            return data
         except ValueError:
             bad_format = True
-        except Exception:
+        except Exception:  # noqa: BLE001, S110
             pass
+        else:
+            LOGGER.debug("got %s from %s", self.msg, self.msg_args)
+            return data
         if bad_format:
-            try:
+            with suppress(OSError):  # reading and writing on the same file may cause race on multiple processes
                 self.remove()
-            except OSError:  # reading and writing on the same file may cause race on multiple processes
-                pass
         return None
 
     def remove(self):
         self.file.unlink()
-        logging.debug(f"removed {self.msg} at %s", *self.msg_args)
+        LOGGER.debug("removed %s at %s", self.msg, self.msg_args)
 
     @contextmanager
     def locked(self):
@@ -154,17 +150,17 @@ class JSONStoreDisk(ContentStore, metaclass=ABCMeta):
         folder = self.file.parent
         folder.mkdir(parents=True, exist_ok=True)
         self.file.write_text(json.dumps(content, sort_keys=True, indent=2), encoding="utf-8")
-        logging.debug(f"wrote {self.msg} at %s", *self.msg_args)
+        LOGGER.debug("wrote %s at %s", self.msg, self.msg_args)
 
 
 class PyInfoStoreDisk(JSONStoreDisk):
-    def __init__(self, in_folder, path):
+    def __init__(self, in_folder, path) -> None:
         key = sha256(str(path).encode("utf-8")).hexdigest()
         super().__init__(in_folder, key, "python info of %s", (path,))
 
 
 class EmbedDistributionUpdateStoreDisk(JSONStoreDisk):
-    def __init__(self, in_folder, distribution):
+    def __init__(self, in_folder, distribution) -> None:
         super().__init__(
             in_folder,
             distribution,
