@@ -3,10 +3,12 @@ from __future__ import annotations
 import logging
 import os
 import sys
+from collections import deque
+from contextlib import suppress
 from pathlib import Path
-from typing import TYPE_CHECKING, Callable
+from typing import TYPE_CHECKING
 
-from virtualenv.info import IS_WIN
+from virtualenv.info import IS_WIN, fs_path_id
 
 from .discover import Discover
 from .py_info import PythonInfo
@@ -14,19 +16,23 @@ from .py_spec import PythonSpec
 
 if TYPE_CHECKING:
     from argparse import ArgumentParser
-    from collections.abc import Generator, Iterable, Mapping, Sequence
+    from collections.abc import Callable, Generator, Iterable, Mapping, Sequence
 
     from virtualenv.app_data.base import AppData
+LOGGER = logging.getLogger(__name__)
 
 
 class Builtin(Discover):
-    python_spec: Sequence[str]
+    python_spec: Sequence[str] | deque[str]
     app_data: AppData
     try_first_with: Sequence[str]
 
     def __init__(self, options) -> None:
         super().__init__(options)
         self.python_spec = options.python or [sys.executable]
+        if self._env.get("VIRTUALENV_PYTHON"):
+            self.python_spec = deque(self.python_spec)
+            self.python_spec.rotate(-1)
         self.app_data = options.app_data
         self.try_first_with = options.try_first_with
 
@@ -69,22 +75,22 @@ def get_interpreter(
     key, try_first_with: Iterable[str], app_data: AppData | None = None, env: Mapping[str, str] | None = None
 ) -> PythonInfo | None:
     spec = PythonSpec.from_string_spec(key)
-    logging.info("find interpreter for spec %r", spec)
+    LOGGER.info("find interpreter for spec %r", spec)
     proposed_paths = set()
     env = os.environ if env is None else env
     for interpreter, impl_must_match in propose_interpreters(spec, try_first_with, app_data, env):
         key = interpreter.system_executable, impl_must_match
         if key in proposed_paths:
             continue
-        logging.info("proposed %s", interpreter)
+        LOGGER.info("proposed %s", interpreter)
         if interpreter.satisfies(spec, impl_must_match):
-            logging.debug("accepted %s", interpreter)
+            LOGGER.debug("accepted %s", interpreter)
             return interpreter
         proposed_paths.add(key)
     return None
 
 
-def propose_interpreters(  # noqa: C901, PLR0912
+def propose_interpreters(  # noqa: C901, PLR0912, PLR0915
     spec: PythonSpec,
     try_first_with: Iterable[str],
     app_data: AppData | None = None,
@@ -92,6 +98,7 @@ def propose_interpreters(  # noqa: C901, PLR0912
 ) -> Generator[tuple[PythonInfo, bool], None, None]:
     # 0. try with first
     env = os.environ if env is None else env
+    tested_exes: set[str] = set()
     for py_exe in try_first_with:
         path = os.path.abspath(py_exe)
         try:
@@ -99,7 +106,12 @@ def propose_interpreters(  # noqa: C901, PLR0912
         except OSError:
             pass
         else:
-            yield PythonInfo.from_exe(os.path.abspath(path), app_data, env=env), True
+            exe_raw = os.path.abspath(path)
+            exe_id = fs_path_id(exe_raw)
+            if exe_id in tested_exes:
+                continue
+            tested_exes.add(exe_id)
+            yield PythonInfo.from_exe(exe_raw, app_data, env=env), True
 
     # 1. if it's a path and exists
     if spec.path is not None:
@@ -109,29 +121,44 @@ def propose_interpreters(  # noqa: C901, PLR0912
             if spec.is_abs:
                 raise
         else:
-            yield PythonInfo.from_exe(os.path.abspath(spec.path), app_data, env=env), True
+            exe_raw = os.path.abspath(spec.path)
+            exe_id = fs_path_id(exe_raw)
+            if exe_id not in tested_exes:
+                tested_exes.add(exe_id)
+                yield PythonInfo.from_exe(exe_raw, app_data, env=env), True
         if spec.is_abs:
             return
     else:
         # 2. otherwise try with the current
-        yield PythonInfo.current_system(app_data), True
+        current_python = PythonInfo.current_system(app_data)
+        exe_raw = str(current_python.executable)
+        exe_id = fs_path_id(exe_raw)
+        if exe_id not in tested_exes:
+            tested_exes.add(exe_id)
+            yield current_python, True
 
         # 3. otherwise fallback to platform default logic
         if IS_WIN:
             from .windows import propose_interpreters  # noqa: PLC0415
 
             for interpreter in propose_interpreters(spec, app_data, env):
+                exe_raw = str(interpreter.executable)
+                exe_id = fs_path_id(exe_raw)
+                if exe_id in tested_exes:
+                    continue
+                tested_exes.add(exe_id)
                 yield interpreter, True
     # finally just find on path, the path order matters (as the candidates are less easy to control by end user)
-    tested_exes = set()
     find_candidates = path_exe_finder(spec)
     for pos, path in enumerate(get_paths(env)):
-        logging.debug(LazyPathDump(pos, path, env))
+        LOGGER.debug(LazyPathDump(pos, path, env))
         for exe, impl_must_match in find_candidates(path):
-            if exe in tested_exes:
+            exe_raw = str(exe)
+            exe_id = fs_path_id(exe_raw)
+            if exe_id in tested_exes:
                 continue
-            tested_exes.add(exe)
-            interpreter = PathPythonInfo.from_exe(str(exe), app_data, raise_on_error=False, env=env)
+            tested_exes.add(exe_id)
+            interpreter = PathPythonInfo.from_exe(exe_raw, app_data, raise_on_error=False, env=env)
             if interpreter is not None:
                 yield interpreter, impl_must_match
 
@@ -143,11 +170,11 @@ def get_paths(env: Mapping[str, str]) -> Generator[Path, None, None]:
             path = os.confstr("CS_PATH")
         except (AttributeError, ValueError):
             path = os.defpath
-    if not path:
-        return None
-    for p in map(Path, path.split(os.pathsep)):
-        if p.exists():
-            yield p
+    if path:
+        for p in map(Path, path.split(os.pathsep)):
+            with suppress(OSError):
+                if p.exists():
+                    yield p
 
 
 class LazyPathDump:
@@ -180,7 +207,10 @@ def path_exe_finder(spec: PythonSpec) -> Callable[[Path], Generator[tuple[Path,
 
     def path_exes(path: Path) -> Generator[tuple[Path, bool], None, None]:
         # 4. then maybe it's something exact on PATH - if it was direct lookup implementation no longer counts
-        yield (path / direct), False
+        direct_path = path / direct
+        if direct_path.exists():
+            yield direct_path, False
+
         # 5. or from the spec we can deduce if a name on path matches
         for exe in path.iterdir():
             match = pat.fullmatch(exe.name)
